@@ -371,11 +371,11 @@ let pp_systemdefn fd m sd lookup fn =
       output_string fd "(* for interactive use:\n";
       output_string fd "  app load [\"pred_setTheory\",\"finite_mapTheory\",\"stringTheory\",\"containerTheory\",\"ottLib\"];\n";
       output_string fd "*)\n\n";
-      output_string fd "open HolKernel boolLib Parse bossLib ottLib;\n"  ;
+      output_string fd "open HolKernel boolLib Parse bossLib ottLib;\n";
       output_string fd "infix THEN THENC |-> ## ;\n";
       output_string fd "local open arithmeticTheory stringTheory containerTheory pred_setTheory listTheory \n";
       output_string fd "  finite_mapTheory in end;\n\n";
-      Printf.fprintf fd "val _ = new_theory \"%s\";\n\n" fn; 
+      Printf.fprintf fd "val _ = new_theory \"%s\";\n" fn;
       pp_systemdefn_core fd m sd lookup;
       output_string fd "\nval _ = export_theory ();\n"
   | Coq co ->
@@ -464,15 +464,15 @@ let pp_systemdefn_core_io m sd lookup oi merge_fragments =
            | Hol ho ->
                [ Embed_string (dummy_loc,
                  "(* generated by Ott "^Version.n^" from: "^file_sources^" *)\n"
-                 ^ "(* to compile: Holmake "^fn^"Theory.uo   *)\n" 
+                 ^ "(* to compile: Holmake "^fn^"Theory.uo   *)\n"
                  ^ "(* for interactive use:\n"
                  ^ "  app load [\"pred_setTheory\",\"finite_mapTheory\",\"stringTheory\",\"containerTheory\",\"ottLib\"];\n"
                  ^"*)\n\n"
-                 ^ "open HolKernel boolLib Parse bossLib ottLib;\n"  
+                 ^ "open HolKernel boolLib Parse bossLib ottLib;\n"
                  ^ "infix THEN THENC |-> ## ;\n"
                  ^ "local open arithmeticTheory stringTheory containerTheory pred_setTheory listTheory \n"
                  ^ "  finite_mapTheory in end;\n\n"
-                 ^ "val _ = new_theory \""^fn^"\";\n\n")] 
+                 ^ "val _ = new_theory \""^fn^"\";\n")]
            | Coq co ->
                [ Embed_string (dummy_loc,
 	           "(* generated by Ott " ^ Version.n ^ " from: " ^ file_sources ^ " *)\n\n"
